@@ -16,11 +16,11 @@ except:
 os.environ["POL_PORT"] = "0"
 os.environ["PLAYONLINUX"] = os.path.realpath(os.path.realpath(__file__)+"/../../../")
 os.environ["SITE"] = "http://repository.playonlinux.com"
-os.environ["VERSION"] = "4.2.6"
+os.environ["VERSION"] = "4.2.10"
 os.environ["POL_ID"] = str(random.randint(1, 100000000))
-os.environ["WINE_SITE"] = "http://www.playonlinux.com/wine/binaries"
-os.environ["GECKO_SITE"] = "http://www.playonlinux.com/wine/gecko"
-os.environ["MONO_SITE"] = "http://www.playonlinux.com/wine/mono"
+os.environ["WINE_SITE"] = "http://wine.playonlinux.com/binaries"
+os.environ["GECKO_SITE"] = "http://wine.playonlinux.com/gecko"
+os.environ["MONO_SITE"] = "http://wine.playonlinux.com/mono"
 homedir = os.environ["HOME"]
 
 # Debian packagers should switch this to TRUE
@@ -31,7 +31,7 @@ os.environ["DEBIAN_PACKAGE"] = "FALSE"
 # Variables PlayOnMac
 if os.environ["POL_OS"] == "Mac":
     os.environ["PLAYONMAC"] = os.environ["PLAYONLINUX"]
-    os.environ["REPERTOIRE"] = os.environ["HOME"]+"/Library/PlayOnMac/"
+    os.environ["POL_USER_ROOT"] = os.environ["HOME"]+"/Library/PlayOnMac/"
     os.environ["APPLICATION_TITLE"] = "PlayOnMac"
     os.environ["POL_DNS"] = "playonmac.com"
     windows_add_size = 20;
@@ -42,7 +42,7 @@ if os.environ["POL_OS"] == "Mac":
 
 # Variables PlayOnLinux
 if os.environ["POL_OS"] == "Linux":
-    os.environ["REPERTOIRE"] = os.environ["HOME"]+"/.PlayOnLinux/"
+    os.environ["POL_USER_ROOT"] = os.environ["HOME"]+"/.PlayOnLinux/"
     os.environ["APPLICATION_TITLE"] = "PlayOnLinux"
     os.environ["POL_DNS"] = "playonlinux.com"
     if playonlinux.VersionLower(wx.VERSION_STRING, "3.0.0"):
@@ -66,7 +66,7 @@ if os.environ["POL_OS"] == "Linux":
             os.environ["POL_WGET"] = "env LD_LIBRARY_PATH=\"\" wget --prefer-family=IPv4 -q"
             
 if os.environ["POL_OS"] == "FreeBSD":
-    os.environ["REPERTOIRE"] = os.environ["HOME"]+"/.PlayOnBSD/"
+    os.environ["POL_USER_ROOT"] = os.environ["HOME"]+"/.PlayOnBSD/"
     os.environ["APPLICATION_TITLE"] = "PlayOnBSD"
     os.environ["POL_DNS"] = "playonlinux.com"
     windows_add_size = 0
@@ -90,9 +90,9 @@ else:
     os.environ["AMD64_COMPATIBLE"] = "False"
 
 # Variables mixtes
-os.environ["POL_USER_ROOT"] = os.environ["REPERTOIRE"]
+os.environ["REPERTOIRE"] = os.environ["POL_USER_ROOT"]
 os.environ["TITRE"] = os.environ["APPLICATION_TITLE"]
-os.environ["WINEPREFIX"] = os.environ["REPERTOIRE"]+"/wineprefix/default"
+os.environ["WINEPREFIX"] = os.environ["POL_USER_ROOT"]+"/wineprefix/default"
 os.environ["OS_NAME"] = os_name
 
 # Wine
@@ -116,9 +116,9 @@ if os.environ["POL_OS"] == "Mac":
 
     os.environ["PATH"] = os.environ["PLAYONLINUX"]+"/../unix/wine/bin:" + os.environ["PLAYONLINUX"]+"/../unix/image_magick/bin:" + os.environ["PLAYONLINUX"]+"/../unix/tools/bin/:" + os.environ["PATH"]
 
-    os.environ["LD_LIBRARY_PATH"] =  os.environ["PLAYONLINUX"]+"/../unix/wine/lib/:"  + os.environ["PLAYONLINUX"]+"/../unix/image_magick/lib:"+ os.environ["PLAYONLINUX"]+"/../unix/tools/lib/ld:/usr/X11/lib/:" + os.environ["LD_LIBRARY_PATH"]
+    os.environ["WRITE_LD"] =  os.environ["PLAYONLINUX"]+"/../unix/image_magick/lib:"+ os.environ["PLAYONLINUX"]+"/../unix/tools/lib/ld:/opt/X11/lib/:" + os.environ["LD_LIBRARY_PATH"]
 
-    os.environ["DYLD_LIBRARY_PATH"] = os.environ["PLAYONLINUX"]+"/../unix/tools/lib/dyld:" + os.environ["PLAYONLINUX"]+"/../unix/image_magick/lib:"+ os.environ["DYLD_LIBRARY_PATH"]
+    os.environ["WRITE_DYLD"] = os.environ["PLAYONLINUX"]+"/../unix/tools/lib/dyld:" + os.environ["PLAYONLINUX"]+"/../unix/image_magick/lib:"+ os.environ["DYLD_LIBRARY_PATH"]
 else:
     # Debian maintainer decided for some reason not to let wineserver binary into PATH...
     for winepath in ('/usr/lib/i386-linux-gnu/wine/bin', '/usr/lib/i386-linux-gnu/wine-unstable/bin',
@@ -138,7 +138,7 @@ except KeyError:
 os.environ["DYLDPATH_ORIGIN"] = os.environ["DYLD_LIBRARY_PATH"]
 
 playonlinux_env = os.environ["PLAYONLINUX"]
-playonlinux_rep = os.environ["REPERTOIRE"]
+playonlinux_rep = os.environ["POL_USER_ROOT"]
 version = os.environ["VERSION"]
 current_user = os.environ["USER"]
 
@@ -152,3 +152,6 @@ if playonlinux.GetSettings("PROXY_ENABLED") == "1":
         else:
             http_proxy = "http://"+playonlinux.GetSettings("PROXY_LOGIN")+":"+playonlinux.GetSettings("PROXY_PASSWORD")+"@"+playonlinux.GetSettings("PROXY_URL")+":"+playonlinux.GetSettings("PROXY_PORT")
         os.environ["http_proxy"] = http_proxy
+
+
+userAgent = "PlayOnLinux/" + os.environ["VERSION"]
