@@ -19,7 +19,8 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 encoding = 'utf-8'
 
-import os, getopt, sys, urllib, signal, string, time, webbrowser, gettext, locale, sys, shutil, subprocess
+import os, getopt, sys, urllib, signal, string, time, webbrowser, gettext, locale, sys
+import shlex, subprocess, signal
 
 try :
     os.environ["POL_OS"]
@@ -284,7 +285,7 @@ class MainWindow(wx.Frame):
         self.optionmenu = wx.Menu()
 
 
-        self.optionmenu.Append(221, _("Internet"))
+        self.optionmenu.Append(211, _("Internet"))
         self.optionmenu.Append(212, _("File associations"))
         self.optionmenu.Append(214, _("Plugin manager"))
 
@@ -549,6 +550,7 @@ class MainWindow(wx.Frame):
                 self.installFrame.panelItems.Hide()
                 self.installFrame.panelManual.Hide()
                 self.installFrame.panelWait.Show()
+                self.installFrame.manualInstall.Raise()
                 try:
                     if(self.playing == False):
                         self.installFrame.animation_wait.Play()
@@ -564,6 +566,7 @@ class MainWindow(wx.Frame):
                     self.installFrame.panelManual.Show()
                 else:
                     self.installFrame.panelItems.Show()
+                    self.installFrame.manualInstall.Raise()
                 self.installFrame.panelWait.Hide()
                 self.installFrame.animation_wait.Stop()
                 self.playing = False
@@ -610,10 +613,10 @@ class MainWindow(wx.Frame):
 
 
     def RWineConfigurator(self, event):
-        self.RConfigure(_("Configure Wine"), "nothing")
+        self.RConfigure("winecfg")
 
     def RKill(self, event):
-        self.RConfigure(_("KillApp"), "nothing")
+        self.RConfigure("kprocess")
 
     def ReadMe(self, event):
         game_exec = self.GetSelectedProgram()
@@ -623,7 +626,7 @@ class MainWindow(wx.Frame):
             wx.MessageBox(_("No manual found for {0}").format(game_exec), os.environ["APPLICATION_TITLE"])
 
     def RRegistryEditor(self, event):
-        self.RConfigure(_("Registry Editor"), "nothing")
+        self.RConfigure("regedit")
 
     def run_plugin(self, event):
         game_exec = self.GetSelectedProgram()
@@ -717,7 +720,7 @@ class MainWindow(wx.Frame):
             self.IconFilename=self.IconDialog.GetFilename()
             self.IconDirname=self.IconDialog.GetDirectory()
             IconFile=os.path.join(self.IconDirname,self.IconFilename)
-            self.RConfigure("IconChange", IconFile)
+            self.RConfigure("changeicon", IconFile)
             self.IconDialog.Destroy()
             #Pop-up menu for game list: ending
 
@@ -758,7 +761,7 @@ class MainWindow(wx.Frame):
         self.menuGaucheAddLink("pol_prgm_settings", _("Settings"), i,Variables.playonlinux_env+"/resources/images/menu/settings.png",self.Options)
 
 
-        if(os.path.exists(os.environ["PLAYONLINUX"]+"/.git/")):
+        if(os.path.exists(Variables.playonlinux_env+"/.git/")):
             i+=1
             self.menuGaucheAddLink("pol_git", _("Update GIT"), i,Variables.playonlinux_env+"/resources/images/menu/update_git.png",self.UpdateGIT)
         elif "POL_UPTODATE" in os.environ and os.environ["POL_UPTODATE"] == "FALSE":
@@ -909,11 +912,11 @@ class MainWindow(wx.Frame):
             self.removeTool.Enable(False)
 
 
-    def RConfigure(self, function_to_run, firstargument):
+    def RConfigure(self, function_to_run, *args):
         """Starts polconfigurator remotely."""
         game_exec = self.GetSelectedProgram()
         if game_exec != "":
-            subprocess.Popen(["bash", Variables.playonlinux_env+"/bash/polconfigurator", game_exec, function_to_run, firstargument])
+            subprocess.Popen(["bash", Variables.playonlinux_env+"/bash/polconfigurator", game_exec, function_to_run] + list(args))
         else:
             wx.MessageBox(_("Please select a program."), os.environ["APPLICATION_TITLE"])
 
@@ -1056,15 +1059,27 @@ class MainWindow(wx.Frame):
 
     def POLDie(self):
         for pid in self.registeredPid:
-            os.system("kill -9 -%d 2> /dev/null" % pid)
-            os.system("kill -9 %d 2> /dev/null" % pid) 
+            try:
+                os.kill(-pid, signal.SIGKILL)
+            except OSError:
+                pass
+            try:
+                os.kill(pid, signal.SIGKILL)
+            except OSError:
+                pass
         app.POLServer.closeServer()
         os._exit(0)
 
     def POLRestart(self):
         for pid in self.registeredPid:
-            os.system("kill -9 -%d 2> /dev/null" % pid)
-            os.system("kill -9 %d 2> /dev/null" % pid) 
+            try:
+                os.kill(-pid, signal.SIGKILL)
+            except OSError:
+                pass
+            try:
+                os.kill(pid, signal.SIGKILL)
+            except OSError:
+                pass
         app.POLServer.closeServer()
         os._exit(63) # Restart code
 
@@ -1107,7 +1122,7 @@ class MainWindow(wx.Frame):
         self.aboutBox.SetName(os.environ["APPLICATION_TITLE"])
         self.aboutBox.SetVersion(Variables.version)
         self.aboutBox.SetDescription(_("Run your Windows programs on "+os.environ["POL_OS"]+" !"))
-        self.aboutBox.SetCopyright("© 2007-2013 "+_("PlayOnLinux and PlayOnMac team\nUnder GPL licence version 3"))
+        self.aboutBox.SetCopyright("© 2007-2015 "+_("PlayOnLinux and PlayOnMac team\nUnder GPL licence version 3"))
         self.aboutBox.AddDeveloper(_("Developer and Website: ")+"Tinou (Pâris Quentin), MulX (Petit Aymeric)")
         self.aboutBox.AddDeveloper(_("Scriptors: ")+"GNU_Raziel")
         self.aboutBox.AddDeveloper(_("Packager: ")+"MulX (Petit Aymeric), Tinou (Pâris Quentin)")
@@ -1128,7 +1143,7 @@ class PlayOnLinuxApp(wx.App):
         close = False
         exe_present = False
 
-        os.system("bash "+Variables.playonlinux_env+"/bash/startup")
+        subprocess.call(["bash", Variables.playonlinux_env+"/bash/startup"])
         self.systemCheck()
         
         for f in  sys.argv[1:]:
@@ -1157,7 +1172,7 @@ class PlayOnLinuxApp(wx.App):
                  os._exit(0)
                  break
             i+=1 
-        os.system("bash \"$PLAYONLINUX/bash/startup_after_server\" &")
+        subprocess.Popen(["bash", Variables.playonlinux_env + "/bash/startup_after_server"])
    
         self.SetTopWindow(self.frame)
         self.frame.Show(True)
@@ -1202,7 +1217,7 @@ class PlayOnLinuxApp(wx.App):
 
         #### 32 bits OpenGL check
         try:
-            returncode=subprocess.call([os.environ["PLAYONLINUX"]+"/bash/check_gl","x86"])
+            returncode=subprocess.call([Variables.playonlinux_env+"/bash/check_gl","x86"])
         except:
             returncode=255
         if(os.environ["POL_OS"] == "Linux" and returncode != 0):
@@ -1214,7 +1229,7 @@ class PlayOnLinuxApp(wx.App):
         #### 64 bits OpenGL check
         if(os.environ["AMD64_COMPATIBLE"] == "True"):
             try:
-                returncode=subprocess.call([os.environ["PLAYONLINUX"]+"/bash/check_gl","amd64"])
+                returncode=subprocess.call([Variables.playonlinux_env+"/bash/check_gl","amd64"])
             except:
                 returncode=255
         if(os.environ["AMD64_COMPATIBLE"] == "True" and os.environ["POL_OS"] == "Linux" and returncode != 0):
@@ -1226,7 +1241,7 @@ class PlayOnLinuxApp(wx.App):
         #### Filesystem check
         if(os.environ["POL_OS"] == "Linux"):
             try:
-                returncode=subprocess.call([os.environ["PLAYONLINUX"]+"/bash/check_fs"])
+                returncode=subprocess.call([Variables.playonlinux_env+"/bash/check_fs"])
             except:
                 returncode=255
             if(os.environ["POL_OS"] == "Linux" and returncode != 0):
@@ -1249,6 +1264,8 @@ class PlayOnLinuxApp(wx.App):
         
         self.singleCheckFatal("gpg", package="GnuPG")
 
+        # FIXME: now that PoL can use a range of terminal emulators, xterm is no longer
+        # a hard dependency
         if(os.environ["DEBIAN_PACKAGE"] == "FALSE" and os.environ["POL_OS"] != "Mac"):
             self.singleCheck("xterm")
         self.singleCheck("gettext.sh", package="gettext")  # gettext-base on Debian
@@ -1283,16 +1300,16 @@ class PlayOnLinuxApp(wx.App):
             if(":\\\\\\\\" in exec_app):
                 exec_app = exec_app.replace("\\\\","\\")
             try:
-                os.system("cd \""+cd_app+"\" && "+exec_app+" &")
+                subprocess.Popen(shlex.split(exec_app),cwd=cd_app)
             except:
                 pass
 
         elif(file_extension == "exe" or file_extension == "EXE"):
-            os.system("bash \"$PLAYONLINUX/bash/run_exe\" \""+filename+"\" &")
+            subprocess.Popen(["bash", Variables.playonlinux_env + "/bash/run_exe", filename])
 
         elif(file_extension == "pol" or file_extension == "POL"):
             if(wx.YES == wx.MessageBox(_('Are you sure you want to  want to install {0} package?').format(filename).decode("utf-8","replace"), os.environ["APPLICATION_TITLE"],style=wx.YES_NO | wx.ICON_QUESTION)):
-                os.system("bash \"$PLAYONLINUX/bash/playonlinux-pkg\" -i \""+filename+"\" &")
+                subprocess.Popen(["bash", Variables.playonlinux_env + "/bash/playonlinux-pkg", "-i", filename])
         else:
             playonlinux.open_document(filename,file_extension.lower())
  
@@ -1304,7 +1321,7 @@ class PlayOnLinuxApp(wx.App):
         if(os.environ["POL_OS"] == "FreeBSD" and not "playonbsd://" in url):
             wx.MessageBox(_("You are trying to open a script design for {0}! It might not work as expected").format("PlayOnMac or PlayOnLinux"), os.environ["APPLICATION_TITLE"])
             
-        os.system("bash \"$PLAYONLINUX/bash/playonlinux-url_handler\" \""+url+"\" &")
+        subprocess.Popen(["bash", Variables.playonlinux_env + "/bash/playonlinux-url_handler", url])
 
     def MacReopenApp(self):
         #sys.exit()
